/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for abstract ABOUT dialog class
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)AbstractAboutDialog.java    1.0 2001/06/07
 *
 * Copyright (c) 2001 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;

import java.awt.Frame;
import javax.swing.JPanel;


/**
 * AbstractAboutDialog - Creates a generic ABOUT dialog.
 *
 * @version 1.0 2001/06/07
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
abstract public class AbstractAboutDialog extends AbstractDialog
{
    // =========================================================================
    // CONSTRUCTORS
    // =========================================================================

    /**
     * Class constructor specifying title
     *
     * @param title  string specifying dialog title
     */
    public AbstractAboutDialog(String title)
    {
        this((Frame)null, title);
    }

    /**
     * Class constructor specifying owner and title
     *
     * @param owner  parent component
     * @param title  string specifying dialog title
     */
    public AbstractAboutDialog(Frame owner, String title)
    {
        super(owner, title);
        setName("AbstractAboutDialog");
    }

    // =========================================================================
    // PUBLIC INTERFACE
    // =========================================================================

    /**
     * Displays the dialog on the screen, centered on its parent
     */ 
    public void display()
    {
        centerOnParent();
        setVisible(true);
        requestFocus();
    }

    // =========================================================================
    // ABSTRACT METHODS
    // =========================================================================

    /**
     * Creates the banner panel displayed as the main pane
     * in the tabbed pane.
     *
     * @return <code>JPanel</code> representing about panel
     */
    abstract protected JPanel createAboutPanel();

    /**
     * Creates a pane for displaying contact information
     *
     * @return <code>JPanel</code> representing contact panel
     */
    abstract protected JPanel createContactPanel();

    /**
     * Creates a pane for displaying developer credits, et cetera.
     *
     * @return <code>JPanel</code> representing credits panel
     */
    abstract protected JPanel createCreditsPanel();

    /**
     * Creates a pane for displaying information about the
     * Java Runtime Environment.
     *
     * @return <code>JPanel</code> representing JRE information panel
     */
    abstract protected JPanel createSysInfoPanel();
}

