/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for Internet protocol handler class
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)InetProtocolHandler.java    1.0 2001/08/25
 *
 * Copyright (c) 2001 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkListener;


/**
 * InetProtocolHandler - Routes internet protocol requests.
 *
 * @version 1.0 2001/08/27
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
public class InetProtocolHandler
    implements HyperlinkListener
{
    // =========================================================================
    // IMPLEMENT HYPERLINKLISTENER
    // =========================================================================

    /**
     * Called when a hypertext link is updated. If activated, dispatches the
     * request to a web browser to handle opening the URL.
     *
     * @param event  hyperlink event
     */
    public void hyperlinkUpdate(HyperlinkEvent event)
    {
        if (event.getEventType() == HyperlinkEvent.EventType.ACTIVATED)
            openURL(event.getURL());
    }

    // =========================================================================
    // CLASS INTERFACE
    // =========================================================================

    /**
     * Opens the requested URL.
     *
     * @param url  URL to display
     * @see #openURL(String)
     */
    public static void openURL(URL url)
    {
        openURL(url.toString());
    }

    /**
     * Opens the requested URL.
     *
     * @param url  string representing URL to display
     * @see #openURL(URL)
     */
    public static void openURL(String url)
    {
        Thread browserThread;

        System.out.println("Attempting to open URL <" + url + ">");
        browserThread = new Thread(new BrowserInvocation(url));
        browserThread.start();
        // :TODO: - Need to allow OS to reclaim thread resources
    }
}


/**
 * BrowserInvocation - Used to avoid hanging caller while browser is running.
 *
 * @version 1.00 2001/09/01
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
class BrowserInvocation
    implements Runnable
{
    // =========================================================================
    // CONSTRUCTOR
    // =========================================================================

    /**
     * Class constructor specifying url
     *
     * @param url  URL to display
     */
    BrowserInvocation(String url)
    {
        this.url = url;
    }

    // =========================================================================
    // IMPLEMENT RUNNABLE
    // =========================================================================

    /**
     * Thread entry-point for BrowserInvocation object.
     * Dispatches the request to a web browser to display the requested URL.
     *
     * @see edu.stanford.ejalbert.BrowserLauncher#openURL
     */
    public void run()
    {
        try
        {
            edu.stanford.ejalbert.BrowserLauncher.openURL(url);
        }
        catch (MalformedURLException mue)
        {
            System.err.println(mue);
        }
        catch (IOException ioe)
        {
            System.err.println(ioe);
        }
    }

    // =========================================================================
    // OBJECT ATTRIBUTES
    // =========================================================================

    private String url;
}

