/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for non whitespace textfield validation class
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)NonWhitespaceValidator.java    1.0 2002/03/17
 *
 * Copyright (c) 2002 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;


/**
 * NonWhitespaceValidator - Implements non whitespace validation.
 *
 * @version 1.0 2002/03/17
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
public class NonWhitespaceValidator extends ValidationAdapter
{
    // =========================================================================
    // IMPLEMENTS VALIDATOR
    // =========================================================================

    /**
     * Determines whether the data is blank or not.
     *
     * @param value  object with data to be checked
     * @return       true if data is valid; otherwise, false
     */
    public boolean isValid(Object value)
    {
        boolean valid = false;

        if (value != null)
            valid = (value.toString().trim().length() != 0);

        return valid;
    }

    // =========================================================================
    // CLASS INTERFACE
    // =========================================================================

    /**
     * Convenience function that determines whether the data is blank without
     * the caller having to have an instance of this class available.
     *
     * @param value  data to be checked
     * @return       true if data is valid; otherwise, false
     * @see #isValid
     */
    public static boolean accepts(Object value)
    {
        return new NonWhitespaceValidator().isValid(value);
    }
}

