##################### FILE ABSTRACT ############################################
##
## Synopsis::         Source for Demo Plaid 1g model routines
##
## File Name::        %M%
## Version::          %I%
## Type::             source
## Date Completed::   %G%
##
## Environment::
##     Language::     Splus
##     Computer::     Compaq/Alpha
##     OS::           DigitalUNIX
##     OSVersion::    4.0
##
## Module Information::
##     Owner::        MDACC
##     Department::   Biostatistics
##     Researcher::   Kim-Anh Do
##     Application::  geneclust
##
################################################################################

Plaid1g.func<-function(N,p,amplitude)
{
## Creates a plaid type matrix with 3 non overlapping clusters
## and overlayed Gaussian noise

    # Check matrix size constraints
    minN<-30;
    minp<-30;
    if (is.numeric(N) && N < minN)
        stop(paste("#rows =",N,", min =",minN,"\n"));
    if (is.numeric(p) && p < minp)
        stop(paste("#columns =",p,", min =",minp,"\n"));

    # Amplitude of the clusters
    a<-c(rep(amplitude,3));
    # Size of each cluster in "genes"(rows)
    n<-c(as.integer(N/10),as.integer(N/10),as.integer(N/10));
    # Size of each cluster in "cells"(cols)
    r<-c(as.integer(p*0.75),as.integer(p*0.75),as.integer(p*0.60));
    # Beginning row of each cluster
    first<-as.integer(N/10+N/3);
    second<-2*first;
    nb<-c(1,first,second);

    X<-matrix(0,nrow=N,ncol=p);

    rsecond <-as.integer(p-r[2]);
    rthird  <-as.integer((p-r[3])/2);
    X[nb[1]:(nb[1]+n[1]),1:r[1]]<-a[1]
    X[nb[2]:(nb[2]+n[2]),rsecond:r[2]]<-a[2]
    X[nb[3]:(nb[3]+n[3]),rthird:(rthird+r[3])]<-a[3]

    return(X);
}

GCDemoPlaid1g.func<-function(nclst,percentToShave,nperm,gapTolerance,N,p,a,
                             noise,df,percentSupervision,classificationFileName)
{
    cat("PK_MONITOR_CREATE_MATRIX\n");

    X<-Plaid1g.func(N,p,a);
    Data<-Common.func(X,
                      N,
                      p,
                      nclst,
                      percentToShave,
                      nperm,
                      gapTolerance,
                      noise,
                      df,
                      percentSupervision,
                      classificationFileName);

    return(Data);
}

